@@ -1,4 +1,4 @@
-/* $Id: mem.h,v 1.23 2003/10/20 20:11:58 hadess Exp $ */
+/* $Id: mem.h,v 1.25 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -55,7 +55,7 @@ struct _glibtop_mem
 		locked;		/* GLIBTOP_MEM_LOCKED	*/
 };
 
-#define glibtop_get_mem(mem)	glibtop_get_mem_l(glibtop_global_server, mem)
+void glibtop_get_mem(glibtop_mem *buf);
 
 #if GLIBTOP_SUID_MEM
 #define glibtop_get_mem_r		glibtop_get_mem_p
@@ -73,16 +73,6 @@ void glibtop_init_mem_s (glibtop *server);
 void glibtop_get_mem_s (glibtop *server, glibtop_mem *buf);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_mem [];
-extern const unsigned glibtop_types_mem [];
-extern const char *glibtop_labels_mem [];
-extern const char *glibtop_descriptions_mem [];
-
-#endif
 
 G_END_DECLS
 
