@@ -1,4 +1,4 @@
-/* $Id: proctime.h,v 1.25 2003/10/20 20:11:58 hadess Exp $ */
+/* $Id: proctime.h,v 1.28 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -51,14 +51,14 @@ typedef struct _glibtop_proc_time	glibtop_proc_time;
 struct _glibtop_proc_time
 {
 	guint64	flags,
-		start_time,	/* start time of process -- 
+		start_time,	/* start time of process --
 				 * seconds since 1-1-70 */
 		rtime,		/* real time accumulated by process */
 		utime,		/* user-mode CPU time accumulated by process */
 		stime,		/* kernel-mode CPU time accumulated by process */
-		cutime,		/* cumulative utime of process and 
+		cutime,		/* cumulative utime of process and
 				 * reaped children */
-		cstime,		/* cumulative stime of process and 
+		cstime,		/* cumulative stime of process and
 				 * reaped children */
 		timeout,	/* The time (in jiffies) of the process's
 				 * next timeout */
@@ -70,7 +70,8 @@ struct _glibtop_proc_time
 		xcpu_stime [GLIBTOP_NCPU];	/* SMP machines. */
 };
 
-#define glibtop_get_proc_time(p1, p2)	glibtop_get_proc_time_l(glibtop_global_server, p1, p2)
+
+void glibtop_get_proc_time(glibtop_proc_time *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_TIME
 #define glibtop_get_proc_time_r	glibtop_get_proc_time_p
@@ -88,16 +89,6 @@ void glibtop_init_proc_time_s (glibtop *server);
 void glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf, pid_t pid);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_proc_time [];
-extern const unsigned glibtop_types_proc_time [];
-extern const char *glibtop_labels_proc_time [];
-extern const char *glibtop_descriptions_proc_time [];
-
-#endif
 
 G_END_DECLS
 
