@@ -1,4 +1,4 @@
-/* $Id: msg_limits.c,v 1.21 2005/12/12 09:38:11 jamesh Exp $ */
+/* $Id: msg_limits.c,v 1.22 2006/04/09 10:50:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -45,11 +45,11 @@ glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
 
 #else
 
-/* #define KERNEL to get declaration of `struct msginfo'. */
-
-#if (defined(__FreeBSD__) && (__FreeBSD_version < 410000)) || (defined __bsdi__)
+/* Define the appropriate macro (if any) to get declaration of `struct
+ * msginfo'.  Needed on, at least, FreeBSD. */
+#if defined (STRUCT_MSGINFO_NEEDS_KERNEL)
 #define KERNEL 1
-#else
+#elif defined (STRUCT_MSGINFO_NEEDS__KERNEL)
 #define _KERNEL 1
 #endif
 
