@@ -1,4 +1,4 @@
-/* $Id: proctime.c,v 1.31 2005/12/12 09:38:11 jamesh Exp $ */
+/* $Id: proctime.c,v 1.32 2006/04/04 20:01:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -138,11 +138,6 @@ glibtop_get_proc_time_p (glibtop *server, glibtop_proc_time *buf,
 #if (defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000))
 	if (server->sysdeps.proc_time == 0)
 		return;
-
-#ifndef __bsdi__
-	sprintf (filename, "/proc/%d/mem", (int) pid);
-	if (stat (filename, &statb)) return;
-#endif
 #endif
 
 	/* Get the process information */
