@@ -1,4 +1,4 @@
-/* $Id: msg_limits.c,v 1.18 2005/12/12 09:38:12 jamesh Exp $ */
+/* $Id: msg_limits.c,v 1.19 2006/04/02 09:16:20 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -52,7 +52,7 @@ glibtop_get_msg_limits_s (glibtop *server, glibtop_msg_limits *buf)
 
 	memset (buf, 0, sizeof (glibtop_msg_limits));
 
-	msgctl (0, IPC_INFO, (struct msqid_ds *) &msginfo);
+	msgctl (0, IPC_INFO, (void*) &msginfo);
 
 	buf->msgpool = msginfo.msgpool;
 	buf->msgmap = msginfo.msgmap;
